1.0.4
=====

* Fixed compatibility with Sphinx 1.4


1.0.3
=====

* Fixed "self" parameter not being removed from exception class constructor signatures
* Fixed process_signature() erroneously removing the first argument of a static method


1.0.2
=====

* Fixed exception classes not being processed like normal classes


1.0.1
=====

* Fixed errors caused by forward references not being looked up with the right globals


1.0.0
=====

* Initial release
